pytilities.stringifiable — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »

# pytilities.stringifiable

class `pytilities.stringifiable.` `Stringifiable`

  Mixin that provides a reasonable default __str__.

  `__str__`()

    Returns the class name

  `__weakref__`

    list of weak references to the object (if defined)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »